﻿using System;
using System.Reflection;

namespace ProjectCruiser.CollectionGenericObj;

// Параметризованный набор объектов
public class ListGenObj<T> : ICollectionGenObj<T>
    where T : class
{
    // Список объектов, которые храним
    private readonly List<T?> _collection;

    // Максимально допустимое число объектов в списке
    private int _maxCount;
    public int Count => _collection.Count;

    public int SetMaxCount { set { if (value > 0) { _maxCount = value; } } }

    public ListGenObj()
    {
        _collection = new();
    }

    public T? GetItem(int position)
    {
        if (position >= Count || position < 0)
        {
            return null;
        }

        return _collection[position];
    }

    public int Insert(T obj)
    {
        if (Count >= _maxCount || obj == null)
        {
            return -1;
        }

        _collection.Add(obj);
        return Count;
    }

    public int Insert(T obj, int position)
    {
        if (position >= _maxCount || Count >= _maxCount ||
            position < 0 || _collection[position] != null
            || obj == null)
        {
            return -1;
        }

        _collection.Insert(position, obj);
        return position;
    }

    public T? Remove(int position)
    {
        if (position >= Count || position < 0)
        // on the other positions items don't exist
        {
            return null;
        }

        T? item = _collection[position];
        _collection.RemoveAt(position);
        return item;
    }
}
